# mypy-boto3-personalize-events

[![PyPI - mypy-boto3-personalize-events](https://img.shields.io/pypi/v/mypy-boto3-personalize-events.svg?color=blue)](https://pypi.org/project/mypy-boto3-personalize-events)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-personalize-events.svg?color=blue)](https://pypi.org/project/mypy-boto3-personalize-events)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-personalize-events?color=blue)](https://pypistats.org/packages/mypy-boto3-personalize-events)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.PersonalizeEvents 1.17.67](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/personalize-events.html#PersonalizeEvents)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-personalize-events docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_personalize_events/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-personalize-events](#mypy-boto3-personalize-events)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `PersonalizeEvents` service.

```bash
python -m pip install boto3-stubs[personalize-events]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[personalize-events]` in your environment:
  `python -m pip install 'boto3-stubs[personalize-events]'`

Both type checking and auto-complete should work for `PersonalizeEvents`
service. No explicit type annotations required, write your `boto3` code as
usual.

### PyCharm

- Install `boto-stubs[personalize-events]` in your environment:
  `python -m pip install 'boto3-stubs[personalize-events]'`

Both type checking and auto-complete should work for `PersonalizeEvents`
service. No explicit type annotations required, write your `boto3` code as
usual. Auto-complete can be slow on big projects or if you have a lot of
installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[personalize-events]` in your environment:
  `python -m pip install 'boto3-stubs[personalize-events]'`
- Run `mypy` as usual

Type checking should work for `PersonalizeEvents` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[personalize-events]` in your environment:
  `python -m pip install 'boto3-stubs[personalize-events]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `PersonalizeEvents` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`PersonalizeEventsClient` provides annotations for
`boto3.client("personalize-events")`.

```python
import boto3

from mypy_boto3_personalize_events import PersonalizeEventsClient

client: PersonalizeEventsClient = boto3.client("personalize-events")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: PersonalizeEventsClient = session.client("personalize-events")
```

### Typed dictionaries

`mypy_boto3_personalize_events.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_personalize_events.type_defs import (
    EventTypeDef,
    ItemTypeDef,
    UserTypeDef,
)

def get_structure() -> EventTypeDef:
    return {
      ...
    }
```
